-- !!!!!!!!!!!!!!!!!!!!!!!!!!!! ANALYSE PAR DATE !!!!!!!!!!!!!!!!!!!

-- !!!!!!!!!!!!!!!!!!!! ANALYSE PAR JDA !!!!!!!!!!!!!!!!!!!!!!!!!!!
SELECT d.jda, count(*) as nb
FROM f_dw_dates d, f_dw_ticket ti
WHERE d.DATE_VENTE = ti.FK_DATE
GROUP BY d.jda
ORDER BY nb DESC;

-- !!!!!!!!!!!! ANALYSE PAR MOIS, TRIMESTRE, ANNEE EN ROLLUP !!!!!!!!
SELECT d.annee, d.trimestre, d.mois, count(*)
FROM f_dw_dates d, f_dw_ticket ti
WHERE d.DATE_VENTE = ti.FK_DATE
GROUP BY ROLLUP (d.annee, d.trimestre, d.mois)
ORDER BY d.annee, d.trimestre, d.mois;


-- !!!!!!!!!!!!!!!!!! ANALYSE PAR JDS !!!!!!!!!!!!
SELECT d.jds, COUNT(*) AS q
FROM f_dw_ticket ti, f_dw_dates d
WHERE ti.fk_date=d.date_vente AND jds <> 'EXCEPTION'
GROUP BY d.jds
ORDER BY q desc;

-- MOYENNE DU NOMBRE DE VENTE PAR JDS
SELECT avg(q) FROM
(
  SELECT d.jds AS jds, COUNT(*) AS q
  FROM f_dw_ticket ti, f_dw_dates d
  WHERE ti.FK_DATE=d.DATE_VENTE AND d.jds <> 'EXCEPTION'
  GROUP BY d.jds
  ORDER BY q desc
);
--WHERE jds <> 'saturday';


-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ANALYSE PAR PRODUIT !!!!!!!!!!!!!!!!!!!!!!!!!!
-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-- Type de sabre le plus achete par espece

SELECT cu.CustomerNumber, cu.Species, p.ptype, count(*)
FROM f_dw_product p, f_dw_ticket ti, f_dw_customer cu
WHERE p.Product = ti.Fk_product AND cu.customerNumber = ti.fk_customer AND Species <> 'ERROR' AND PTYPE <>'Error'
GROUP BY cu.CustomerNumber, cu.Species, p.ptype;

SELECT distinct(fk_customer) FROM f_dw_ticket;

SELECT count(*) from f_dw_customer where species ='Humans';
-- Espece qui achete le plus
SELECT cu.SPECIES, count(*) as nb
FROM f_dw_customer cu, f_dw_ticket ti
WHERE cu.customernumber = ti.FK_CUSTOMER
GROUP BY cu.species;


-- ANALYSE DES VENTES PAR TYPE DE SABRE EN PROPORTION

SELECT p.ptype AS r1, COUNT(*) AS q1
FROM f_dw_ticket ti, f_dw_product p
WHERE ti.FK_PRODUCT=p.product AND ptype <> 'Error'
GROUP BY p.ptype;

-- NOMBRE DE PRODUITS DANS LE CATALOGUE PAR TYPE DE PRODUIT
SELECT p.ptype AS r2, COUNT(*) AS q2
FROM f_dw_product p
WHERE p.ptype <> 'Error'
GROUP BY p.ptype;

-- !!!!!!!!! AJOUT DE LA PROPORTION !!!!!!!!!!!!!!!!!!!!
SELECT r1 AS Type, q1 AS Ventes, q2 AS NbProduits, ROUND(q1/q2) AS VentesParType FROM
  (SELECT p.ptype AS r1, COUNT(*) AS q1
  FROM f_dw_ticket ti, f_dw_product p
  WHERE ti.FK_PRODUCT = p.product and p.ptype <> 'Error'
  GROUP BY p.ptype),
  (SELECT p.ptype AS r2, COUNT(*) AS q2
  FROM f_dw_product p
  WHERE p.ptype <> 'Erreur'
  GROUP BY p.ptype)
WHERE r1=r2
ORDER BY ventesParType DESC;


-- !!!!!!!!!!!! MOYENNE DES VENTES PAR PRODUIT !!!!!!!!!!!!!!!!!!!
SELECT ROUND(AVG(ventes)) FROM
(
SELECT COUNT(*) AS ventes
FROM f_dw_ticket v, f_dw_product p
WHERE p.product=v.fk_product
GROUP BY p.product
);

-- !!!!!!!!!!! NOMBRE DE VENTE DES BS !!!!!!!!!!!!!!!!!!!!!
SELECT p.product AS r1, count(*) as NbVentesBS
FROM f_dw_ticket ti, f_dw_product p
WHERE p.bestseller = '1' AND ti.fk_product = p.product
GROUP BY p.product
ORDER BY NbVentes DESC;

-- !!!!!!!!!!! Nombre de ventes total pour les BS !!!!!!!!!!
SELECT p.bestSeller, count(*) AS nbVentesBS
FROM f_dw_ticket ti, f_dw_product p
WHERE p.product = ti.fk_product AND p.product <> 'ERREUR 1' AND p.product <> 'ERREUR 2'
GROUP BY p.BESTSELLER;


-- NOMBRE DE PRODUITS DANS LE CATALOGUE PAR BS
SELECT p.bestseller AS r2, COUNT(*) AS q2
FROM f_dw_product p
WHERE p.product <> 'ERREUR 1' AND p.product <> 'ERREUR 2'
GROUP BY p.bestseller;

SELECT r1 AS BestSeller, q1 AS Ventes, q2 AS NbProduits, ROUND(q1/q2) AS VentesParType FROM
  (SELECT p.bestSeller AS r1, count(*) AS q1
FROM f_dw_ticket ti, f_dw_product p
WHERE p.product = ti.fk_product AND p.product <> 'ERREUR 1' AND p.product <> 'ERREUR 2'
GROUP BY p.BESTSELLER),
  (SELECT p.bestseller AS r2, COUNT(*) AS q2
FROM f_dw_product p
WHERE p.product <> 'ERREUR 1' AND p.product <> 'ERREUR 2'
GROUP BY p.bestseller)
WHERE r1 = r2
ORDER BY ventesParType DESC;


-- !!!!!!!!!!! ANALYSE DES VENTES PAR JDS ET PAR CARACTERISTIQUES DES PRODUITS !!!!!!!!!!!!!!!!!!!!!!
SELECT d.jds, p.SegWeight, p.PSegSize, p.PType, count(*)
FROM f_dw_ticket ti, f_dw_dates d, f_dw_product p
WHERE p.product=ti.FK_PRODUCT AND d.date_vente = ti.FK_DATE AND d.jds <> 'EXCEPTION' AND p.PType <> 'Error' AND p.PsegSize <> 'Erreur' AND p.SegWeight <> 'Erreur'
GROUP BY d.jds, p.SegWeight, p.PSegSize, p.PType;

-- !!!!!!!!!!!! TEST DE REQUETE EN CUBE !!!!!!!!!!!!!!!!!!!!!!!!!!!
-- DONNE TOUTES LES COMBINAISONS POSSIBLES ENTRE LES ATTRIBUTS GROUPE
SELECT p.SegWeight, p.PsegSize, count(*) as nbprod
FROM f_dw_product p
WHERE p.SegWeight <> 'Erreur' AND p.PSegSize <> 'Erreur'
GROUP BY CUBE (p.SegWeight, p.PSegSize);

SELECT DISTINCT(income)
FROM f_dw_customer
ORDER BY income desc;